Documentation
¶
Overview ¶
Package cmd provides the CLI commands for Spotigo
Index ¶
Constants ¶
const ( // MaxInputLength is the maximum allowed length for user input MaxInputLength = 4096 // MaxConversationHistory limits the number of messages kept in context MaxConversationHistory = 50 )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ArtistCount ¶
ArtistCount tracks artist frequency
type GenreCount ¶
GenreCount tracks genre frequency
type LibraryStats ¶
type LibraryStats struct {
TotalTracks int
TotalPlaylists int
TotalArtists int
UniqueAlbums int
TopArtists []ArtistCount
TopGenres []GenreCount
PlaylistStats []PlaylistStat
}
LibraryStats holds computed statistics about the music library
type PlaylistStat ¶
PlaylistStat holds playlist statistics
Click to show internal directories.
Click to hide internal directories.